@@ -129,8 +129,6 @@ class SOPClass(Dataset):
         # to a file in PS3.10 format.
         self.preamble = b'\x00' * 128
         self.file_meta = FileMetaDataset()
-        self.file_meta.DICOMPrefix = 'DICM'
-        self.file_meta.FilePreamble = self.preamble
         self.file_meta.TransferSyntaxUID = UID(transfer_syntax_uid)
         self.file_meta.MediaStorageSOPClassUID = UID(sop_class_uid)
         self.file_meta.MediaStorageSOPInstanceUID = UID(sop_instance_uid)
@@ -283,7 +281,7 @@ class SOPClass(Dataset):
     def copy_patient_and_study_information(self, dataset: Dataset) -> None:
         """Copies patient- and study-related metadata from `dataset` that
         are defined in the following modules: Patient, General Study,
-        Patient Study, Clinical Trial Subject, and Clinical Trial Study.
+        Patient Study, Clinical Trial Subject and Clinical Trial Study.
 
         Parameters
         ----------
