@@ -1,5 +1,10 @@
+import math
+import itertools
+
 import pytest
 
+from pydicom.dataset import Dataset
+
 from highdicom import PlanePositionSequence
 from highdicom.enum import CoordinateSystemNames
 from highdicom.utils import compute_plane_position_tiled_full
@@ -102,7 +107,7 @@ def test_compute_plane_position_tiled_full(inputs, expected_output):
     assert output == expected_output
 
 
-def test_should_raise_error_when_3d_param_is_missing():
+def test_compute_plane_position_tiled_full_with_missing_parameters():
     with pytest.raises(TypeError):
         compute_plane_position_tiled_full(
             row_index=1,
@@ -115,6 +120,7 @@ def test_should_raise_error_when_3d_param_is_missing():
             pixel_spacing=(1.0, 1.0),
             slice_index=1
         )
+
     with pytest.raises(TypeError):
         compute_plane_position_tiled_full(
             row_index=1,
@@ -127,3 +133,34 @@ def test_should_raise_error_when_3d_param_is_missing():
             pixel_spacing=(1.0, 1.0),
             spacing_between_slices=1.0
         )
+
+
+def compute_plane_position_slide_per_frame():
+    iterator = itertools.product(range(1, 4), range(1, 3))
+    for num_optical_paths, num_focal_planes in iterator:
+        image = Dataset()
+        image.Rows = 4
+        image.Columns = 4
+        image.TotalPixelMatrixRows = 16
+        image.TotalPixelMatrixColumns = 16
+        image.TotalPixelMatrixFocalPlanes = num_focal_planes
+        image.NumberOfOpticalPaths = num_optical_paths
+        image.ImageOrientationSlide = [0.0, 1.0, 0.0, 1.0, 0.0, 0.0]
+        shared_fg_item = Dataset()
+        pixel_measures_item = Dataset()
+        pixel_measures_item.PixelSpacing = [1.0, 1.0]
+        pixel_measures_item.SliceThickness = 1.0
+        pixel_measures_item.SpacingBetweenSlices = 1.0
+        shared_fg_item.PixelMeasuresSequence = [pixel_measures_item]
+        image.SharedFunctionalGroupsSequence = [shared_fg_item]
+
+        plane_positions = compute_plane_position_tiled_full(image)
+
+        tiles_per_column = math.ceil(image.TotalPixelMatrixRows / image.Rows)
+        tiles_per_row = math.ceil(image.TotalPixelMatrixColumns / image.Columns)
+        assert len(plane_positions) == math.prod([
+            num_optical_paths,
+            num_focal_planes,
+            tiles_per_row,
+            tiles_per_column
+        ])
